@@ -76,8 +76,11 @@ def package_list(context, data_dict):
     col = (package_revision_table.c.id
         if api == 2 else package_revision_table.c.name)
     query = _select([col])
-    query = query.where(_and_(package_revision_table.c.state=='active',
-        package_revision_table.c.current==True))
+    query = query.where(_and_(
+                package_revision_table.c.state=='active',
+                package_revision_table.c.current==True,
+                package_revision_table.c.private==False,
+                ))
     query = query.order_by(col)
     return list(zip(*query.execute())[0])
 
@@ -1841,8 +1844,9 @@ def get_site_user(context, data_dict):
         user.sysadmin = True
         model.Session.add(user)
         model.Session.flush()
-        if not context.get('defer_commit'):
-            model.Session.commit()
+    if not context.get('defer_commit'):
+        model.repo.commit_and_remove()
+
     return {'name': user.name,
             'apikey': user.apikey}
 
