@@ -23,7 +23,7 @@ def package_update(context, data_dict):
         )
     else:
         # If dataset is not owned then we can edit if config permissions allow
-        if new_authz.auth_is_registered_user():
+        if not new_authz.auth_is_anon_user(context):
             check1 = new_authz.check_config_permission(
                 'create_dataset_if_not_in_organization')
         else:
