@@ -21,6 +21,7 @@ from ckan.logic.validators import (package_id_not_changed,
                                    duplicate_extras_key,
                                    ignore_not_package_admin,
                                    ignore_not_group_admin,
+                                   ignore_not_sysadmin,
                                    no_http,
                                    tag_not_uppercase,
                                    user_name_validator,
@@ -30,6 +31,7 @@ from ckan.logic.validators import (package_id_not_changed,
                                    user_password_not_empty,
                                    isodate,
                                    int_validator,
+                                   natural_number_validator,
                                    boolean_validator,
                                    user_about_validator,
                                    vocabulary_name_validator,
@@ -39,12 +41,16 @@ from ckan.logic.validators import (package_id_not_changed,
                                    user_id_or_name_exists,
                                    object_id_validator,
                                    activity_type_exists,
+                                   resource_id_exists,
                                    tag_not_in_vocabulary,
                                    group_id_exists,
                                    owner_org_validator,
                                    user_name_exists,
                                    role_exists,
-                                   url_validator)
+                                   url_validator,
+                                   datasets_with_no_organization_cannot_be_private,
+                                   list_of_strings,
+                                   )
 from ckan.logic.converters import (convert_user_name_or_id_to_id,
                                    convert_package_name_or_id_to_id,
                                    convert_group_name_or_id_to_id,)
@@ -133,7 +139,8 @@ def default_create_package_schema():
         'type': [ignore_missing, unicode],
         'owner_org': [owner_org_validator, unicode],
         'log_message': [ignore_missing, unicode, no_http],
-        'private': [ignore_missing, boolean_validator],
+        'private': [ignore_missing, boolean_validator,
+            datasets_with_no_organization_cannot_be_private],
         '__extras': [ignore],
         '__junk': [empty],
         'resources': default_resource_schema(),
@@ -180,10 +187,7 @@ def default_show_package_schema():
     schema['id'] = []
 
     schema.update({
-        'tags': {
-            '__extras': [ckan.lib.navl.validators.keep_extras]
-            },
-        })
+        'tags': {'__extras': [ckan.lib.navl.validators.keep_extras]}})
 
     # Add several keys to the 'resources' subschema so they don't get stripped
     # from the resource dicts by validation.
@@ -384,6 +388,7 @@ def default_user_schema():
         'about': [ignore_missing, user_about_validator, unicode],
         'created': [ignore],
         'openid': [ignore_missing],
+        'sysadmin': [ignore_missing, ignore_not_sysadmin],
         'apikey': [ignore],
         'reset_key': [ignore],
         'activity_streams_email_notifications': [ignore_missing],
@@ -452,14 +457,15 @@ def default_create_activity_schema():
     schema = {
         'id': [ignore],
         'timestamp': [ignore],
-        'user_id': [not_missing, not_empty, unicode, user_id_exists],
+        'user_id': [not_missing, not_empty, unicode,
+            convert_user_name_or_id_to_id],
         'object_id': [not_missing, not_empty, unicode, object_id_validator],
         # We don't bother to validate revision ID, since it's always created
         # internally by the activity_create() logic action function.
         'revision_id': [],
         'activity_type': [not_missing, not_empty, unicode,
             activity_type_exists],
-        'data': [ignore_empty, ignore_missing, unicode],
+        'data': [ignore_empty, ignore_missing],
     }
     return schema
 
@@ -475,7 +481,6 @@ def default_follow_dataset_schema():
 
 
 def member_schema():
-
     schema = {
         'id': [group_id_exists, unicode],
         'username': [user_name_exists, unicode],
@@ -488,3 +493,70 @@ def default_follow_group_schema():
     schema = {'id': [not_missing, not_empty, unicode,
         convert_group_name_or_id_to_id]}
     return schema
+
+
+def default_package_list_schema():
+    schema = {
+        'limit': [ignore_missing, natural_number_validator],
+        'offset': [ignore_missing, natural_number_validator],
+        'page': [ignore_missing, natural_number_validator]
+    }
+    return schema
+
+
+def default_pagination_schema():
+    schema = {
+        'limit': [ignore_missing, natural_number_validator],
+        'offset': [ignore_missing, natural_number_validator]
+    }
+    return schema
+
+
+def default_dashboard_activity_list_schema():
+    schema = default_pagination_schema()
+    schema['id'] = [unicode]
+    return schema
+
+
+def default_autocomplete_schema():
+    schema = {
+        'q': [not_missing, unicode],
+        'limit': [ignore_missing, natural_number_validator]
+    }
+    return schema
+
+
+def default_package_search_schema():
+    schema = {
+        'q': [ignore_missing, unicode],
+        'fq': [ignore_missing, unicode],
+        'rows': [ignore_missing, natural_number_validator],
+        'sort': [ignore_missing, unicode],
+        'start': [ignore_missing, natural_number_validator],
+        'qf': [ignore_missing, unicode],
+        'facet': [ignore_missing, unicode],
+        'facet.mincount': [ignore_missing, natural_number_validator],
+        'facet.limit': [ignore_missing, natural_number_validator],
+        'facet.field': [ignore_missing, list_of_strings],
+        'extras': [ignore_missing]  # Not used by Solr, but useful for extensions
+    }
+    return schema
+
+
+def default_resource_search_schema():
+    schema = {
+        'query': [ignore_missing],  # string or list of strings
+        'fields': [ignore_missing],  # dict of fields
+        'order_by': [ignore_missing, unicode],
+        'offset': [ignore_missing, natural_number_validator],
+        'limit': [ignore_missing, natural_number_validator]
+    }
+    return schema
+
+
+def create_schema_for_required_keys(keys):
+    ''' helper function that creates a schema definition where
+    each key from keys is validated against ``not_missing``.
+    '''
+    schema = dict([(x, [not_missing]) for x in keys])
+    return schema
