@@ -9,6 +9,8 @@ import ckan.plugins as p
 import ckan.model as model
 from ckan.common import OrderedDict, _, c
 
+import ckan.lib.maintain as maintain
+
 log = getLogger(__name__)
 
 # This is a private cache used by get_auth_function() and should never
@@ -297,12 +299,34 @@ def check_config_permission(permission):
         return CONFIG_PERMISSIONS[permission]
     return False
 
-
-
+@maintain.deprecated('Use auth_is_loggedin_user instead')
 def auth_is_registered_user():
+    '''
+    This function is deprecated, please use the auth_is_loggedin_user instead
+    '''
+    return auth_is_loggedin_user()
+
+def auth_is_loggedin_user():
     ''' Do we have a logged in user '''
     try:
         context_user = c.user
     except TypeError:
         context_user = None
     return bool(context_user)
+
+def auth_is_anon_user(context):
+    ''' Is this an anonymous user?
+        eg Not logged in if a web request and not user defined in context
+        if logic functions called directly
+
+        See ckan/lib/base.py:232 for pylons context object logic
+    '''
+    try:
+        is_anon_user = (not bool(c.user) and bool(c.author))
+    except TypeError:
+        # No c object set, this is not a call done via the web interface,
+        # but directly, eg from an extension
+        context_user = context.get('user')
+        is_anon_user = not bool(context_user)
+
+    return is_anon_user
