@@ -1,6 +1,6 @@
 import os
-from paste.deploy import appconfig
 import paste.fixture
+from pylons import config
 
 from ckan.config.middleware import make_app
 from ckan.tests import conf_dir, url_for, CreateTestData
@@ -10,24 +10,19 @@ import ckan.model as model
 class TestStorageController:
     @classmethod
     def setup_class(cls):
-        config = appconfig('config:test.ini', relative_to=conf_dir)
-        config.local_conf['ckan.storage.directory'] = '/tmp'
-        wsgiapp = make_app(config.global_conf, **config.local_conf)
+        cls._original_config = config.copy()
+        config['ckan.storage.directory'] = '/tmp'
+        wsgiapp = make_app(config['global_conf'], **config)
         cls.app = paste.fixture.TestApp(wsgiapp)
         CreateTestData.create()
 
     @classmethod
     def teardown_class(cls):
+        config.clear()
+        config.update(cls._original_config)
         model.Session.remove()
         model.repo.rebuild_db()
 
-    def test_02_authorization(self):
-        from ckan.model.authz import Action
-        import ckan.model as model
-        import ckan.authz as authz
-
-        is_authorized = authz.Authorizer.is_authorized(u'tester', Action.UPLOAD_ACTION, model.System()) 
-        assert is_authorized
 
     def test_03_authorization_wui(self):
         url = url_for('storage_upload')
@@ -49,7 +44,7 @@ class TestStorageController:
 
         url = url_for('storage_upload', filepath='xyz.txt')
         out = self.app.get(url, extra_environ=extra_environ)
-        assert 'file/xyz.txt' in out, out        
-    
+        assert 'file/xyz.txt' in out, out
+
     # TODO: test file upload itself
 
