@@ -124,12 +124,11 @@ class MultilingualDataset(SingletonPlugin):
         for key, value in search_data.iteritems():
             if key in KEYS_TO_IGNORE or key.startswith('title'):
                 continue
-            if isinstance(value, list):
-                all_terms.extend(value)
-            elif value in (None, True, False):
-                continue
-            else:
-                all_terms.append(value)
+            if not isinstance(value, list):
+                value = [value]
+            for item in value:
+                if isinstance(item, basestring):
+                    all_terms.append(item)
 
         field_translations = action_get.term_translation_show(
                           {'model': ckan.model},
